@@ -16,17 +16,16 @@ use base 'CPANPLUS::Dist::Base';
 use CPANPLUS::Error; # imported subs: error(), msg()
 use File::Basename;
 use File::Copy      qw[ copy ];
-use File::HomeDir;
 use File::Slurp     qw[ slurp ];
 use IPC::Cmd        qw[ run can_run ];
 use List::Util      qw[ first ];
 use Pod::POM;
 use Readonly;
 
-our $VERSION = '0.3.3';
+our $VERSION = '0.3.4';
 
 Readonly my $DATA_OFFSET => tell(DATA);
-Readonly my $RPMDIR      => File::HomeDir->my_home . '/rpm';
+Readonly my $RPMDIR => do { chomp(my $d=qx[ rpm --eval %_topdir ]); $d; };
 
 
 #--
